==> emelfm2_0.3.5.orig.tar.gz: emelfm2-0.3.5/src/dialogs/e2_mkdir_dialog.h <==
/* $Id: e2_mkdir_dialog.h 469 2007-07-06 22:58:30Z tpgww $

Copyright (C) 2004-2007 tooar <tooar@gmx.net>

This file is part of emelFM2.
emelFM2 is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

emelFM2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with emelFM2; see the file GPL. If not, contact the Free Software
Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#ifndef E2_MKDIR_DIALOG_H
#define E2_MKDIR_DIALOG_H

#include "emelfm2.h"
#include "e2_task.h"

typedef struct _E2_MkdirDialogRuntime
{
	GtkWidget *dialog;
	GtkWidget *scrolled;
	GtkWidget *combo;
	GtkWidget *info_expander;
	GtkWidget *info_box;
//	GtkWidget *info_box;
	GtkWidget *info_label;
	GtkWidget *info_label2;
	GtkWidget *menu;
//	GtkWidget *create_btn;
	gchar *path; //utf-8 encoded
	GList *history;
	gint history_cur;
	gboolean creation_possible;
	gboolean opt_show_last;
	gboolean opt_suggest_dir;
	guint idle_id;
	E2_TaskStatus *status;	//pointer to Q status indicator
} E2_MkdirDialogRuntime;

GtkWidget *e2_mkdir_dialog_create ();
void e2_mkdir_dialog_show ();
void e2_mkdir_dialog_actions_register ();
void e2_mkdir_dialog_options_register ();

#endif //ndef E2_MKDIR_DIALOG_H

==> emelfm2_0.4.1.orig.tar.gz: emelfm2-0.4.1/src/dialogs/e2_mkdir_dialog.h <==
/* $Id: e2_mkdir_dialog.h 874 2008-05-07 14:47:27Z tpgww $

Copyright (C) 2004-2008 tooar <tooar@gmx.net>

This file is part of emelFM2.
emelFM2 is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.

emelFM2 is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with emelFM2; see the file GPL. If not, contact the Free Software
Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#ifndef __E2_MKDIR_DIALOG_H__
#define __E2_MKDIR_DIALOG_H__

#include "emelfm2.h"
#include "e2_task.h"

typedef struct _E2_MkdirDialogRuntime
{
	GtkWidget *dialog;
	GtkWidget *scrolled;
	GtkWidget *combo;
	GtkWidget *info_expander;
//	GtkWidget *info_box;
	GtkWidget *info_label;
	GtkWidget *info_label2;
	GtkWidget *menu;
//	GtkWidget *create_btn;
	gchar *path; //utf-8 encoded
	GList *history;
	gint history_cur;
	gboolean creation_possible;
	gboolean opt_show_last;
	gboolean opt_suggest_dir;
	guint idle_id;
	E2_TaskStatus *status;	//pointer to Q status indicator
} E2_MkdirDialogRuntime;

GtkWidget *e2_mkdir_dialog_create ();
void e2_mkdir_dialog_show ();
void e2_mkdir_dialog_actions_register ();
void e2_mkdir_dialog_options_register ();

#endif //ndef __E2_MKDIR_DIALOG_H__
